#!/bin/bash


find_jar() {
    script_dir="$1"

    # 检查目录是否存在
    if [ ! -d "$script_dir" ]; then
        echo "Wrong script dir：$script_dir"
        return 1
    fi

    # 查找符合规则的 jar 文件
    jar_files=("$script_dir"/ltdts_ora-*.jar)

    # 检查是否存在匹配的 jar 文件
    if [ ${#jar_files[@]} -eq 0 ] || [ ! -e "${jar_files[0]}" ]; then
        echo "Cannot found jar file"
        return 1
    fi

    # 找到最大的版本号的 jar 文件
    max_version=""
    max_version_file=""

    for jar_file in "${jar_files[@]}"; do
        file_name=$(basename "$jar_file")
        version=$(echo "$file_name" | sed -n 's/ltdts_ora_\(.*\)\.jar/\1/p')

        if [[ -z "$max_version" || "$version" > "$max_version" ]]; then
            max_version="$version"
            max_version_file="$jar_file"
        fi
    done

    echo "$max_version_file"
}

script_dir="$(dirname "$(readlink -f "$0")")"
PROGRAM=$(find_jar "$script_dir")
if [ "$?" -ne 0 ]; then
    echo "Cannot find jar file!";
    exit 1
fi
JAVA=java
if [ -n "$JAVA_HOME" ]; then
    JAVA="$JAVA_HOME/bin/java"
fi
JVM_OPTS="${JVM_OPTS:--Xmx8g}"

if [ -n "$ORACLE_INSTANT_CLIENT_BASE" ]; then
    export LD_LIBRARY_PATH="$ORACLE_INSTANT_CLIENT_BASE:$LD_LIBRARY_PATH"
    export PATH="$ORACLE_INSTANT_CLIENT_BASE:$PATH"
    JVM_OPTS="-Dloader.path=$ORACLE_INSTANT_CLIENT_BASE/ojdbc8.jar,$ORACLE_INSTANT_CLIENT_BASE/xstreams.jar $JVM_OPTS"
else
    ORACLE_INSTANT_CLIENT_BASE="$script_dir/instantclient"
    if [ ! -d "$ORACLE_INSTANT_CLIENT_BASE" ]; then
        echo "The environment variable ORACLE_INSTANT_CLIENT_BASE is not set."
        echo "This program requires Oracle Instant Client version 21."
        echo "Please download Oracle Instant Client version 21 and do one of the following:"
        echo "  1. Set the environment variable ORACLE_INSTANT_CLIENT_BASE to the path of the Oracle Instant Client"
        echo "  2. Place Oracle Instant Client version 21 in $script_dir and rename it to 'instantclient'."
        exit 1
    fi
    export LD_LIBRARY_PATH="$ORACLE_INSTANT_CLIENT_BASE:$LD_LIBRARY_PATH"
    export PATH="$ORACLE_INSTANT_CLIENT_BASE:$PATH"
    JVM_OPTS="-Dloader.path=$ORACLE_INSTANT_CLIENT_BASE/ojdbc8.jar,$ORACLE_INSTANT_CLIENT_BASE/xstreams.jar $JVM_OPTS"
fi

"$JAVA" $JVM_OPTS -jar "$PROGRAM" "$@"

